Class: Coradoc::Mirror::Node::Section
- Inherits:
-
Coradoc::Mirror::Node
- Object
- Lutaml::Model::Serializable
- Coradoc::Mirror::Node
- Coradoc::Mirror::Node::Section
- Defined in:
- lib/coradoc/mirror/node.rb
Overview
── Structural containers ──
Defined Under Namespace
Classes: Attrs
Constant Summary collapse
- PM_TYPE =
JS SECTION_TYPES — all deserialize to Section. The type string is preserved as the type attribute on the instance.
'section'- PM_ALIASES =
%w[ clause annex content_section abstract foreword introduction acknowledgements terms definitions references ].freeze